package com.ruoyi.project.ticket.service;

import com.ruoyi.project.ticket.domain.THazardWorkPermit;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2021-10-25
 */
public interface ITHazardWorkPermitService {
    /**
     * 查询【请填写功能名称】
     *
     * @param aId 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    public THazardWorkPermit selectTHazardWorkPermitById(Long aId);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tHazardWorkPermit 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<THazardWorkPermit> selectTHazardWorkPermitList(THazardWorkPermit tHazardWorkPermit);

    /**
     * 新增【请填写功能名称】
     *
     * @param tHazardWorkPermit 【请填写功能名称】
     * @return 结果
     */
    public int insertTHazardWorkPermit(THazardWorkPermit tHazardWorkPermit);

    /**
     * 修改【请填写功能名称】
     *
     * @param tHazardWorkPermit 【请填写功能名称】
     * @return 结果
     */
    public int updateTHazardWorkPermit(THazardWorkPermit tHazardWorkPermit);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param aIds 需要删除的【请填写功能名称】ID
     * @return 结果
     */
    public int deleteTHazardWorkPermitByIds(Long[] aIds);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param aId 【请填写功能名称】ID
     * @return 结果
     */
    public int deleteTHazardWorkPermitById(Long aId);
}
